==> coop-system-client-api-1.0.0-20210512.025937-79-sources.jar: com/xforceplus/ant/system/client/model/MsAdvertiseQueryResponse.java <==
package com.xforceplus.ant.system.client.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.xforceplus.ant.system.client.model.MsAdvertiseModel;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.ArrayList;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonInclude;
import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;
import com.fasterxml.jackson.annotation.JsonIgnore;
import javax.validation.constraints.*;

/**
 * MsAdvertiseQueryResponse
 */

@JsonInclude(NON_NULL)
public class MsAdvertiseQueryResponse {
  @JsonProperty("code")
  private Integer code = null;

  @JsonProperty("message")
  private String message = null;

  @JsonProperty("result")
  private List<MsAdvertiseModel> result = new ArrayList<MsAdvertiseModel>();

  @JsonIgnore
  public MsAdvertiseQueryResponse code(Integer code) {
    this.code = code;
    return this;
  }

   /**
   * return code
   * @return code
  **/
  @ApiModelProperty(value = "return code")
  public Integer getCode() {
    return code;
  }

  public void setCode(Integer code) {
    this.code = code;
  }

  @JsonIgnore
  public MsAdvertiseQueryResponse message(String message) {
    this.message = message;
    return this;
  }

   /**
   * return message
   * @return message
  **/
  @ApiModelProperty(value = "return message")
  public String getMessage() {
    return message;
  }

  public void setMessage(String message) {
    this.message = message;
  }

  @JsonIgnore
  public MsAdvertiseQueryResponse result(List<MsAdvertiseModel> result) {
    this.result = result;
    return this;
  }

  public MsAdvertiseQueryResponse addResultItem(MsAdvertiseModel resultItem) {
    this.result.add(resultItem);
    return this;
  }

   /**
   * 广告数组
   * @return result
  **/
  @ApiModelProperty(value = "广告数组")
  public List<MsAdvertiseModel> getResult() {
    return result;
  }

  public void setResult(List<MsAdvertiseModel> result) {
    this.result = result;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    MsAdvertiseQueryResponse advertiseQueryResponse = (MsAdvertiseQueryResponse) o;
    return Objects.equals(this.code, advertiseQueryResponse.code) &&
        Objects.equals(this.message, advertiseQueryResponse.message) &&
        Objects.equals(this.result, advertiseQueryResponse.result);
  }

  @Override
  public int hashCode() {
    return Objects.hash(code, message, result);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class MsAdvertiseQueryResponse {\n");
    
    sb.append("    code: ").append(toIndentedString(code)).append("\n");
    sb.append("    message: ").append(toIndentedString(message)).append("\n");
    sb.append("    result: ").append(toIndentedString(result)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}

==> coop-system-client-api-1.0.0-20221215.080425-231-sources.jar: com/xforceplus/ant/system/client/model/MsAdvertiseQueryResponse.java <==
package com.xforceplus.ant.system.client.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.xforceplus.ant.system.client.model.MsAdvertiseModel;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.ArrayList;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonInclude;
import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;
import com.fasterxml.jackson.annotation.JsonIgnore;
import javax.validation.constraints.*;

/**
 * MsAdvertiseQueryResponse
 */

@JsonInclude(NON_NULL)
public class MsAdvertiseQueryResponse {
  @JsonProperty("code")
  private Integer code = null;

  @JsonProperty("message")
  private String message = null;

  @JsonProperty("total")
  private Long total = null;

  @JsonProperty("result")
  private List<MsAdvertiseModel> result = new ArrayList<MsAdvertiseModel>();

  @JsonIgnore
  public MsAdvertiseQueryResponse code(Integer code) {
    this.code = code;
    return this;
  }

   /**
   * return code
   * @return code
  **/
  @ApiModelProperty(value = "return code")
  public Integer getCode() {
    return code;
  }

  public void setCode(Integer code) {
    this.code = code;
  }

  @JsonIgnore
  public MsAdvertiseQueryResponse message(String message) {
    this.message = message;
    return this;
  }

   /**
   * return message
   * @return message
  **/
  @ApiModelProperty(value = "return message")
  public String getMessage() {
    return message;
  }

  public void setMessage(String message) {
    this.message = message;
  }

  @JsonIgnore
  public MsAdvertiseQueryResponse total(Long total) {
    this.total = total;
    return this;
  }

   /**
   * 数量
   * @return total
  **/
  @ApiModelProperty(value = "数量")
  public Long getTotal() {
    return total;
  }

  public void setTotal(Long total) {
    this.total = total;
  }

  @JsonIgnore
  public MsAdvertiseQueryResponse result(List<MsAdvertiseModel> result) {
    this.result = result;
    return this;
  }

  public MsAdvertiseQueryResponse addResultItem(MsAdvertiseModel resultItem) {
    this.result.add(resultItem);
    return this;
  }

   /**
   * 广告数组
   * @return result
  **/
  @ApiModelProperty(value = "广告数组")
  public List<MsAdvertiseModel> getResult() {
    return result;
  }

  public void setResult(List<MsAdvertiseModel> result) {
    this.result = result;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    MsAdvertiseQueryResponse advertiseQueryResponse = (MsAdvertiseQueryResponse) o;
    return Objects.equals(this.code, advertiseQueryResponse.code) &&
        Objects.equals(this.message, advertiseQueryResponse.message) &&
        Objects.equals(this.total, advertiseQueryResponse.total) &&
        Objects.equals(this.result, advertiseQueryResponse.result);
  }

  @Override
  public int hashCode() {
    return Objects.hash(code, message, total, result);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class MsAdvertiseQueryResponse {\n");
    
    sb.append("    code: ").append(toIndentedString(code)).append("\n");
    sb.append("    message: ").append(toIndentedString(message)).append("\n");
    sb.append("    total: ").append(toIndentedString(total)).append("\n");
    sb.append("    result: ").append(toIndentedString(result)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}
